//*----------------------------------------------------------------------------
//* AT91SAM7X256 
//*----------------------------------------------------------------------------
//* 
//*
//*----------------------------------------------------------------------------

#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>

#include "Board.h"
#include "swi.h"
#include "serial.h"


#define TIMER0_INTERRUPT_LEVEL   0
#define RTTC_INTERRUPT_LEVEL     0

#define PIV_80ms		    250000

extern volatile uint8_t IRQcause;
extern volatile uint8_t IRQcnt;
uint8_t pIrqHandler = 0;

volatile uint8_t init_device;
volatile char testCAN;
unsigned int txcounter,rxcounter;

volatile int16_t x;


//*----------------------------------------------------------------------------
//* Function Name       : Periodic_Interval_Timer_handler
//* Object              : C handler interrupt function called by the interrupts
//*                       assembling routine
//*----------------------------------------------------------------------------
__ramfunc void Periodic_Interval_Timer_handler(void) 
{	
	volatile uint32_t status;
	
	// Interrupt Acknowledge
	status = AT91C_BASE_PITC->PITC_PIVR;
	
	LED1_TOGGLE();
	
	*AT91C_AIC_EOICR = 0;                     /* End of Interrupt          */
	
}


static void device_init(void)
{
	AT91S_PIO  *pPIOA = AT91C_BASE_PIOA;
	AT91S_RSTC *pRSTC = AT91C_BASE_RSTC;

	
	// Enable User Reset and set its minimal assertion to 960 us
	
	pRSTC->RSTC_RMR = AT91C_RSTC_URSTEN | (0x4<<8) | (unsigned int)(0xA5<<24);
	
	// First, enable the clock of the PIO and set the LEDs in output
	*AT91C_PMC_PCER = (1 << AT91C_ID_PIOA) |  	// Parallel IO Controller
					  (1 << AT91C_ID_US1 );	// USART1 Controller
					 
		
	// Set-up the PIOA
	pPIOA->PIO_OER = LED1 | LED2 ; 			// PIO Output Enable Register
	
	pPIOA->PIO_PER = LED1 | LED2 ;// PIO Enable Register
	pPIOA->PIO_PDR = AT91C_PA5_RXD1 | AT91C_PA6_TXD1 ;    // PIO Disable Register
		
	pPIOA->PIO_ASR = AT91C_PA5_RXD1 | AT91C_PA6_TXD1 ;
				
	// Set-up PIT interrupt
	AT91F_AIC_ConfigureIt ( AT91C_BASE_AIC, AT91C_ID_SYS, RTTC_INTERRUPT_LEVEL,AT91C_AIC_SRCTYPE_INT_POSITIVE_EDGE, (void*)Periodic_Interval_Timer_handler);
	AT91C_BASE_PITC->PITC_PIMR = AT91C_PITC_PITEN | AT91C_PITC_PITIEN | PIV_80ms;  //  IRQ enable CPC
	AT91F_AIC_EnableIt (AT91C_BASE_AIC, AT91C_ID_SYS);
	
	
	LED1_OFF();
	LED2_OFF();
}



int main(void)
{	
	
	device_init(); 	// init interrupts and peripherals
		
	uart1_init();
		
	uart1_puts("\n\rAT91SAM7X256-UART-Demo- SAM7");
	uart1_puts("\n\rinit done\n\r");
	
	
	IntEnable(); // enable INT thru sWI call (not enabled in Cstartup.S)
	
		
		
	while(1)
    {	
	
		uart1_putc(uart1_getc());
		LED2_TOGGLE();
		
    }
}

